@@ -2,7 +2,7 @@
 module ImperativeState where
 import Data.Map
 import Control.Monad.State
-import Control.Monad.Error
+import Control.Monad.Except
 import UrlAnalyse
 import Control.Concurrent.MVar
 import Data.List
@@ -18,10 +18,8 @@ data MyError = DownloadError String String
              | ToManyOptionsError
              | PaperError
  
-instance Error MyError where
-        noMsg = OtherError "A String Error!"
-        strMsg s = OtherError s
- 
+type MyErrorMonad = Either MyError 
+
 instance Show MyError where
         show (DownloadError theLemma theUrl)
           = "Error downloading the lemma \"" ++
@@ -70,7 +68,7 @@ data ImperativeState = ImperativeState{audict ::
 data ImageInfo = ImageInfo{wikiFilename :: String,imageNumber::Integer,contributorUrls::[String],descriptionUrl::URL}
 
  
-type ImperativeMonad = ErrorT MyError (StateT ImperativeState IO)
+type ImperativeMonad = ExceptT MyError (StateT ImperativeState IO)
  
 data RunMode = HTML
              | ExpandedTemplates
