@@ -4,7 +4,6 @@ import ImperativeState
 import Tools
 import UrlAnalyse
 import Control.Monad.State
-import Control.Monad.Error
 import Text.ParserCombinators.Parsec hiding (try)
 import Text.Parsec.Prim
 import Codec.Binary.UTF8.String
@@ -20,6 +19,7 @@ import WikiHelper
 import MediaWikiParseTree
 import MediaWikiParser
 import Network.URL
+import Control.Monad.Except
 import Control.Concurrent
 import Parallel
  
@@ -341,7 +341,7 @@ loadHTML :: ImperativeState -> ImperativeMonad String
 loadHTML st
   = let fu = fullUrl st in
       do midst<-get
-         (res,newst)<-liftIO (runStateT (runErrorT (loadPlain st (Just (url fu)))) midst)
+         (res,newst)<-liftIO (runStateT (runExceptT (loadPlain st (Just (url fu)))) midst)
          case res of 
            Right _->put newst
            _ -> return ()    
