@@ -55,13 +55,17 @@ pageFrame input = H.table H.! A.style "min-width:100%;border:0px;padding:0;borde
                                    do H.ul $
                                         do H.li $ H.a H.! A.href "http://de.wikibooks.org/wiki/Benutzer:Dirk_Huenniger/wb2pdf/manual" $ "Users Manual"
                                            H.li $ H.a H.! A.href "http://de.wikibooks.org/wiki/Benutzer:Dirk_Huenniger/wb2pdf" $ "Project Wiki Page"
-                                           H.li $ H.a H.! A.href "http://sourceforge.net/projects/wb2pdf/files/" $ "Downloads"
+                                           H.li $ H.div H.! A.style "font-size:x-large" $ do 
+                                              H.b $ H.a H.! A.href "http://sourceforge.net/projects/wb2pdf/files/" $ "Download Full Version for Free"
+
                                            H.li $ H.a H.! A.href "http://sourceforge.net/p/wb2pdf/git/ci/master/tree/" $ "Git Sourcecode Repository"
                                            H.li $ H.a H.! A.href "http://de.wikibooks.org/wiki/Benutzer_Diskussion:Dirk_Huenniger/wb2pdf/Requests" $ "Bug Tracker"
                                  H.tr $ infoBox "Web Interface" $
                                    do  mytext "The web interface was artistically designed by Thomas Blume using "
                                        H.a H.! A.href "http://www.yaml.org/" $ "YAML" 
-                                       mytext ". It was technically implemented by Dirk Hünniger using the Blaze Html Framework in Haskell. Important ideas on the design of the user interface were contributed by Georges Khaznadar and Martin Wermers. The server this interface is running on is kindly provided by the Wikimedia foundation."
+                                       mytext ". It was technically implemented by Dirk Hünniger using the Blaze Html Framework in Haskell. Important ideas on the design of the user interface were contributed by Georges Khaznadar and Martin Wermers. The server this interface is running on is run by a private person, who has to cover the costs, so "
+                                       H.b  "please consider downloading the full version for free" 
+                                       mytext " and running at on your own hardware instead of using this server."
 
  
 
@@ -135,11 +139,11 @@ progressBar t sub
                   let oldProgressBarValue = barValue uu
                   let progressBarValue=oldProgressBarValue+(max((p-oldProgressBarValue)*(runtime-(lastRuntime uu))/5.0) 0.0)
                   let prog=if lastReachedKnownRelativeProgress==1.0 then 1000 else if failed uu then  0 else round(progressBarValue*1000.0)::Integer
-                  liftIO $ putMVar t $!! (Data.Map.Strict.insert theIndex uu{barValue=progressBarValue,lastRuntime=runtime} m )
+                  liftIO $ if not (member theIndex m) then putMVar t m else putMVar t $!! (Data.Map.Strict.insert theIndex uu{barValue=progressBarValue,lastRuntime=runtime} m )
                   case filename uu of 
                     Nothing -> do method GET 
                                   ok $
-                                    template "Converting" $ pageFrame $ infoBox (if not (failed uu) then"Conversion Running" else "Conversion Failed due to timeout") $
+                                    template "Converting" $ pageFrame $ infoBox (if not (member theIndex m) then "Not enough resources availiable to process your request! Your request has been dropped! Please download the full version for free and run it on your own computer!" else (if not (failed uu) then"Conversion Running" else "Conversion Failed due to timeout")) $
                                         do H.meta H.! A.httpEquiv "refresh" H.! A.content "1" 
                                            H.table $ 
                                              do H.tr $
@@ -172,6 +176,9 @@ fileFrame t sub
                                ok $
                                     template "Conversion Failed" $ pageFrame $ infoBox "Conversion Failed" $ (mytext "We are sorry the converion failed, please contact our us")
 
+
+currentlyrunning :: Map Int ProgressInfo -> Bool
+currentlyrunning m = not (Data.List.all (\x->(isJust (filename x))||(failed x)) (Data.Map.Strict.elems m)) 
       
 wwidth2 :: [Char]
 wwidth2="width:400px"
@@ -260,12 +267,21 @@ formPage m s
                                       outputFilename = name, inputUrl = (toString (toStrict msg)),
                                       runMode = getRunmode (toString (toStrict expansion)), paper = (toString (toStrict paperOpt)), vector = (toString (toStrict vectorOpt))=="Keep Vector Form",
                                       ImperativeState.copy = Nothing, mainPath = "", server = Nothing,outputType=if (toString (toStrict output)) == "zip" then ImperativeState.ZipArchive else ImperativeState.PlainPDF}
-                                    yy<-newEmptyMVar 
-                                    _<-forkIO $ do (i,o,e,h) <- runInteractiveCommand ("mediawiki2latex -x "++act) 
-                                                   tt<-getPOSIXTime
-                                                   zz<-forkProgressDriver o m name (if (toString (toStrict output) == "zip") then "zip" else "pdf")
-                                                   putMVar yy zz
-                                                   ex h i e ((realToFrac tt)+3600.0) m zz
+                                    yy<-newEmptyMVar
+                                    mm<-takeMVar m 
+                                    _<-if (not (currentlyrunning mm)) 
+                                         then 
+                                           do _<-forkIO $ do (i,o,e,h) <- runInteractiveCommand ("mediawiki2latex -x "++act) 
+                                                             tt<-getPOSIXTime
+                                                             zz<-forkProgressDriver o m name (if (toString (toStrict output) == "zip") then "zip" else "pdf")
+                                                             putMVar yy zz
+                                                             ex h i e ((realToFrac tt)+3600.0) m zz
+                                              return ()  
+                                          else
+                                            do putMVar yy (-1)
+                                               return ()
+                                    putMVar m mm
+
                                     zzzz<-takeMVar yy
                                     return zzzz
                method POST
