@@ -130,7 +130,7 @@ simpleContributors theLemma theHost uu st
   where  
         go :: Anything Char -> (String, String)
         go (Environment Tag (TagAttr _ m) l)
-          = ((shallowFlatten l), findWithDefault "" "href" m)
+          = ((shallowFlatten (deepFlatten l)), findWithDefault "" "href" m)
         go _ = ("", "")
         go2 (c, (a, h)) = (a, h, c, Nothing)
  
