@@ -74,7 +74,7 @@ modpathForExpansion u
 geturl :: String -> IO String
 geturl u
   = if u=="" then return ([]) else Control.Exception.catch
-      (do req0 <- parseUrl u
+      (do req0 <- parseRequest u
           let req
                 = ((urlEncodedBody
                      (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
@@ -94,7 +94,7 @@ geturl u
 geturl2 :: String -> IO BStr.ByteString
 geturl2 u
   = if u=="" then return (BStr.pack []) else Control.Exception.catch
-      (do req0 <- parseUrl u
+      (do req0 <- parseRequest u
           let req
                 = ((urlEncodedBody
                      (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
@@ -113,7 +113,7 @@ geturl2 u
 geturl4 :: String -> String -> IO String
 geturl4 s u
   = if u=="" then return ([]) else Control.Exception.catch
-      (do req1 <- parseUrl (u++"/"++s)
+      (do req1 <- parseRequest (u++"/"++s)
           let req0 = req1 {queryString=UTF8Str.fromString "",path=if (head.reverse$ s)=='?' then (UTF8Str.fromString.(++"%3F").UTF8Str.toString) (path req1) else path req1}
           let req
                 = ((urlEncodedBody
@@ -137,7 +137,7 @@ geturl4 s u
 geturl3 :: String -> String -> String -> IO String
 geturl3 u d s
   = if u=="" then return ([]) else Control.Exception.catch
-      (do req0 <- parseUrl u
+      (do req0 <- parseRequest u
           let req
                 = (urlEncodedBody
                      (map (\ (a, b) -> (UTF8Str.fromString a, UTF8Str.fromString b))
